"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const package_1 = require("./../utils/package");
const config_1 = require("./../utils/config");
const test_1 = require("@schematics/angular/utility/test");
// import {addModuleImportToRootModule} from './../utils/ast';
/*
function addNgBootstrapModuleToAppModule(): Rule {
  return (host: Tree) => {
    addModuleImportToRootModule(host, 'NgbModule.forRoot()', '@ng-bootstrap/ng-bootstrap');
    return host;
  };
}*/
const dependencyVersions = {
    "bootstrap": "^4.4.1",
    "jquery": "3.4.1",
    "popper": "^1.16.1",
    "typesJquery": "3.3.29"
};
function addBootstrapToPackageJson(options) {
    return (host) => {
        package_1.addPackageToPackageJson(host, 'dependencies', 'jquery', `${options.jquery}`);
        package_1.addPackageToPackageJson(host, 'dependencies', 'popper.js', `${options.popper}`);
        package_1.addPackageToPackageJson(host, 'dependencies', 'bootstrap', `${options.bootstrap}`);
        package_1.addPackageToPackageJson(host, 'devDependencies', '@types/jquery', `${options.typesJquery}`);
        return host;
    };
}
function addStyles() {
    return (host) => {
        config_1.addStyle(host, './node_modules/bootstrap/dist/css/bootstrap.css');
        return host;
    };
}
function addScripts() {
    return (host) => {
        config_1.addScript(host, './node_modules/jquery/dist/jquery.min.js');
        config_1.addScript(host, './node_modules/popper.js/dist/umd/popper.min.js');
        config_1.addScript(host, './node_modules/bootstrap/dist/js/bootstrap.min.js');
        return host;
    };
}
function installNodeDeps() {
    return (host, context) => {
        context.addTask(new tasks_1.NodePackageInstallTask());
        return host;
    };
}
function addJqueryPluginToWebpackConfig() {
    return (tree) => {
        const filePath = '/webpack.server.config.js';
        const buffer = tree.read(filePath);
        if (buffer !== null) {
            // Add to configuration and api routes on server.js
            const toAdd = `
  new webpack.ProvidePlugin({
    "window.$": "jquery",
    "window.jQuery": "jquery"
  }),
`;
            const appComponent = test_1.getFileContent(tree, filePath);
            tree.overwrite(filePath, appComponent.replace(`plugins: [`, `plugins: [` + toAdd));
        }
        else {
            console.log('webpack.server.config.js not exist.');
        }
    };
}
function schematicsBootstrap(options) {
    if (!options.bootstrap) {
        options.bootstrap = dependencyVersions.bootstrap;
    }
    if (!options.popper) {
        options.popper = dependencyVersions.popper;
    }
    if (!options.jquery) {
        options.jquery = dependencyVersions.jquery;
    }
    if (!options.typesJquery) {
        options.typesJquery = dependencyVersions.typesJquery;
    }
    return (host, context) => {
        if (!config_1.hasBootstrap(host)) {
            return schematics_1.chain([
                schematics_1.branchAndMerge(schematics_1.chain([
                    addBootstrapToPackageJson(options),
                    (!options.skipWebpackPlugin) ? addJqueryPluginToWebpackConfig() : schematics_1.noop(),
                    addStyles(),
                    addScripts(),
                    installNodeDeps()
                ])),
            ])(host, context);
        }
        else {
            schematics_1.noop();
        }
    };
}
exports.schematicsBootstrap = schematicsBootstrap;
//# sourceMappingURL=index.js.map